%% This file is part of the ANTOMEGA project version 0.7
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2003 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>

% Greek alphabet
\makeletter{"0391}{"03B1}
\makeletter{"0392}{"03B2}
\makeletter{"0393}{"03B3}
\makeletter{"0394}{"03B4}
\makeletter{"0395}{"03B5}
\makeletter{"0396}{"03B6}
\makeletter{"0397}{"03B7}
\makeletter{"0398}{"03B8}
\makeletter{"0399}{"03B9}
\makeletter{"039A}{"03BA}
\makeletter{"039B}{"03BB}
\makeletter{"039C}{"03BC}
\makeletter{"039D}{"03BD}
\makeletter{"039E}{"03BE}
\makeletter{"039F}{"03BF}
\makeletter{"03A0}{"03C0}
\makeletter{"03A1}{"03C1}
\makeletter{"03A3}{"03C2}
\makeletter{"03A3}{"03C3}
\makeletter{"03A4}{"03C4}
\makeletter{"03A5}{"03C5}
\makeletter{"03A6}{"03C6}
\makeletter{"03A7}{"03C7}
\makeletter{"03A8}{"03C8}
\makeletter{"03A9}{"03C9}
 
% letters with dieresis
\makeletter{"03AA}{"03CA}
\makeletter{"03AB}{"03CB}
 
% small letters with tonos
\makelcletter{"0391}{"03AC}
\makelcletter{"0395}{"03AD}
\makelcletter{"0397}{"03AE}
\makelcletter{"0399}{"03AF}
\makelcletter{"039F}{"03CC}
\makelcletter{"03A5}{"03CD}
\makelcletter{"03A9}{"03CE}
 
% capital letters with tonos

% Don't wonder why we are making uppercase characters "same"
% as their lowercase equivalents. They really should have same
% \lccode and \uccode values.

\makesameletter{"0386}{"03AC}
\makesameletter{"0388}{"03AD}
\makesameletter{"0389}{"03AE}
\makesameletter{"038A}{"03AF}
\makesameletter{"038C}{"03CC}
\makesameletter{"038E}{"03CD}
\makesameletter{"038F}{"03CE}
 
% letters with tonos and dieresis
\makelcletter{"03AA}{"0390}
\makelcletter{"03AB}{"03B0}

% alternate forms
\makesameletter{"03D0}{"03B2}
\makesameletter{"03D1}{"03B8}
\makesameletter{"03D2}{"03A5}
\makesameletter{"03D3}{"038E}
\makesameletter{"03D4}{"03AB}
\makesameletter{"03D5}{"03C6}
\makesameletter{"03D6}{"03C0}
\makesameletter{"03F0}{"03BA}
\makesameletter{"03F1}{"03C1}
\makesameletter{"03F2}{"03C3}
\makesameletter{"03F4}{"0398}
\makesameletter{"03F5}{"03B5}

\endinput
