%% This file is part of the ANTOMEGA project version 0.8
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2005 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>

% The Greek extended Unicode range

% Don't wonder why we are making uppercase characters "same"
% as their lowercase equivalents. They really should have same
% \lccode and \uccode values.

% 2005/05/01: Changed settings for Greek letters with oxia:
% they now have exactly the same codes, as their counterparts
% with tonos.
% 2005/05/01: Greek coronis and psili now have the same codes as
% the "regular" right single quote (U+2019).

% alpha with breathings
\makelcletter{"0391}{"1F00}
\makelcletter{"0391}{"1F01}
\makelcletter{"0391}{"1F02}
\makelcletter{"0391}{"1F03}
\makelcletter{"0391}{"1F04}
\makelcletter{"0391}{"1F05}
\makelcletter{"0391}{"1F06}
\makelcletter{"0391}{"1F07}
\makesameletter{"1F08}{"1F00}
\makesameletter{"1F09}{"1F01}
\makesameletter{"1F0A}{"1F02}
\makesameletter{"1F0B}{"1F03}
\makesameletter{"1F0C}{"1F04}
\makesameletter{"1F0D}{"1F05}
\makesameletter{"1F0E}{"1F06}
\makesameletter{"1F0F}{"1F07}

% epsilon with breathings
\makelcletter{"0395}{"1F10}
\makelcletter{"0395}{"1F11}
\makelcletter{"0395}{"1F12}
\makelcletter{"0395}{"1F13}
\makelcletter{"0395}{"1F14}
\makelcletter{"0395}{"1F15}
\makesameletter{"1F18}{"1F10}
\makesameletter{"1F19}{"1F11}
\makesameletter{"1F1A}{"1F12}
\makesameletter{"1F1B}{"1F13}
\makesameletter{"1F1C}{"1F14}
\makesameletter{"1F1D}{"1F15}

% eta with breathings
\makelcletter{"0397}{"1F20}
\makelcletter{"0397}{"1F21}
\makelcletter{"0397}{"1F22}
\makelcletter{"0397}{"1F23}
\makelcletter{"0397}{"1F24}
\makelcletter{"0397}{"1F25}
\makelcletter{"0397}{"1F26}
\makelcletter{"0397}{"1F27}
\makesameletter{"1F28}{"1F20}
\makesameletter{"1F29}{"1F21}
\makesameletter{"1F2A}{"1F22}
\makesameletter{"1F2B}{"1F23}
\makesameletter{"1F2C}{"1F24}
\makesameletter{"1F2D}{"1F25}
\makesameletter{"1F2E}{"1F26}
\makesameletter{"1F2F}{"1F27}

% iota with breathings
\makelcletter{"0399}{"1F30}
\makelcletter{"0399}{"1F31}
\makelcletter{"0399}{"1F32}
\makelcletter{"0399}{"1F33}
\makelcletter{"0399}{"1F34}
\makelcletter{"0399}{"1F35}
\makelcletter{"0399}{"1F36}
\makelcletter{"0399}{"1F37}
\makesameletter{"1F38}{"1F30}
\makesameletter{"1F39}{"1F31}
\makesameletter{"1F3A}{"1F32}
\makesameletter{"1F3B}{"1F33}
\makesameletter{"1F3C}{"1F34}
\makesameletter{"1F3D}{"1F35}
\makesameletter{"1F3E}{"1F36}
\makesameletter{"1F3F}{"1F37}

% omicron with breathings
\makelcletter{"039F}{"1F40}
\makelcletter{"039F}{"1F41}
\makelcletter{"039F}{"1F42}
\makelcletter{"039F}{"1F43}
\makelcletter{"039F}{"1F44}
\makelcletter{"039F}{"1F45}
\makesameletter{"1F48}{"1F40}
\makesameletter{"1F49}{"1F41}
\makesameletter{"1F4A}{"1F42}
\makesameletter{"1F4B}{"1F43}
\makesameletter{"1F4C}{"1F44}
\makesameletter{"1F4D}{"1F45}

% upsilon with breathings
\makelcletter{"03A5}{"1F50}
\makelcletter{"03A5}{"1F51}
\makelcletter{"03A5}{"1F52}
\makelcletter{"03A5}{"1F53}
\makelcletter{"03A5}{"1F54}
\makelcletter{"03A5}{"1F55}
\makelcletter{"03A5}{"1F56}
\makelcletter{"03A5}{"1F57}
\makesameletter{"1F59}{"1F51}
\makesameletter{"1F5B}{"1F53}
\makesameletter{"1F5D}{"1F55}
\makesameletter{"1F5F}{"1F57}

% omega with breathings
\makelcletter{"03A9}{"1F60}
\makelcletter{"03A9}{"1F61}
\makelcletter{"03A9}{"1F62}
\makelcletter{"03A9}{"1F63}
\makelcletter{"03A9}{"1F64}
\makelcletter{"03A9}{"1F65}
\makelcletter{"03A9}{"1F66}
\makelcletter{"03A9}{"1F67}
\makesameletter{"1F68}{"1F60}
\makesameletter{"1F69}{"1F61}
\makesameletter{"1F6A}{"1F62}
\makesameletter{"1F6B}{"1F63}
\makesameletter{"1F6C}{"1F64}
\makesameletter{"1F6D}{"1F65}
\makesameletter{"1F6E}{"1F66}
\makesameletter{"1F6F}{"1F67}

% small letters with oxia and varia
\makelcletter{"0391}{"1F70}
\makesameletter{"1F71}{"03AC}
\makelcletter{"0395}{"1F72}
\makesameletter{"1F73}{"03AD}
\makelcletter{"0397}{"1F74}
\makesameletter{"1F75}{"03AE}
\makelcletter{"0399}{"1F76}
\makesameletter{"1F77}{"03AF}
\makelcletter{"039F}{"1F78}
\makesameletter{"1F79}{"03CC}
\makelcletter{"03A5}{"1F7A}
\makesameletter{"1F7B}{"03DD}
\makelcletter{"03A9}{"1F7C}
\makesameletter{"1F7D}{"03DE}

% accented alpha with ypogegrammeni
\makelcletter{"1FBC}{"1F80}
\makelcletter{"1FBC}{"1F81}
\makelcletter{"1FBC}{"1F82}
\makelcletter{"1FBC}{"1F83}
\makelcletter{"1FBC}{"1F84}
\makelcletter{"1FBC}{"1F85}
\makelcletter{"1FBC}{"1F86}
\makelcletter{"1FBC}{"1F87}
\makesameletter{"1F88}{"1F80}
\makesameletter{"1F89}{"1F81}
\makesameletter{"1F8A}{"1F82}
\makesameletter{"1F8B}{"1F83}
\makesameletter{"1F8C}{"1F84}
\makesameletter{"1F8D}{"1F85}
\makesameletter{"1F8E}{"1F86}
\makesameletter{"1F8F}{"1F87}

% accented eta with ypogegrammeni
\makelcletter{"1FCC}{"1F90}
\makelcletter{"1FCC}{"1F91}
\makelcletter{"1FCC}{"1F92}
\makelcletter{"1FCC}{"1F93}
\makelcletter{"1FCC}{"1F94}
\makelcletter{"1FCC}{"1F95}
\makelcletter{"1FCC}{"1F96}
\makelcletter{"1FCC}{"1F97}
\makesameletter{"1F98}{"1F90}
\makesameletter{"1F99}{"1F91}
\makesameletter{"1F9A}{"1F92}
\makesameletter{"1F9B}{"1F93}
\makesameletter{"1F9C}{"1F94}
\makesameletter{"1F9D}{"1F95}
\makesameletter{"1F9E}{"1F96}
\makesameletter{"1F9F}{"1F97}

% accented omega with ypogegrammeni
\makelcletter{"1FFC}{"1FA0}
\makelcletter{"1FFC}{"1FA1}
\makelcletter{"1FFC}{"1FA2}
\makelcletter{"1FFC}{"1FA3}
\makelcletter{"1FFC}{"1FA4}
\makelcletter{"1FFC}{"1FA5}
\makelcletter{"1FFC}{"1FA6}
\makelcletter{"1FFC}{"1FA7}
\makesameletter{"1FA8}{"1FA0}
\makesameletter{"1FA9}{"1FA1}
\makesameletter{"1FAA}{"1FA2}
\makesameletter{"1FAB}{"1FA3}
\makesameletter{"1FAC}{"1FA4}
\makesameletter{"1FAD}{"1FA5}
\makesameletter{"1FAE}{"1FA6}
\makesameletter{"1FAF}{"1FA7}

% from here we don't follow the Unicode sequence

% combinations with macron/breve
\makeletter{"1FB9}{"1FB1}
\makeletter{"1FD9}{"1FD1}
\makeletter{"1FE9}{"1FE1}
\makeletter{"1FB8}{"1FB0}
\makeletter{"1FD8}{"1FD0}
\makeletter{"1FE8}{"1FE0}

% letters with ypogegrammeni
\makeletter{"1FBC}{"1FB3}
\makeletter{"1FCC}{"1FC3}
\makeletter{"1FFC}{"1FF3}

% Rho with breathings
\makelcletter{"03A1}{"1FE4}
\makelcletter{"03A1}{"1FE5}
\makesameletter{"1FEC}{"1FE5}

% letters with dieresis and oxia
\makelcletter{"03AA}{"1FD3}
\makelcletter{"03AB}{"1FE3}

% letters with dieresis and varia
\makelcletter{"03AA}{"1FD2}
\makelcletter{"03AB}{"1FE2}

% letters with dieresis and perispomeni
\makelcletter{"03AA}{"1FD7}
\makelcletter{"03AB}{"1FE7}

% letters with perispomeni
\makelcletter{"0391}{"1FB6}
\makelcletter{"0397}{"1FC6}
\makelcletter{"0399}{"1FD6}
\makelcletter{"03A5}{"1FE6}
\makelcletter{"03A9}{"1FF6}

% letters with ypogegrammeni and oxia
\makelcletter{"1FBC}{"1FB4}
\makelcletter{"1FCC}{"1FC4}
\makelcletter{"1FFC}{"1FF4}

% letters with ypogegrammeni and varia
\makelcletter{"1FBC}{"1FB2}
\makelcletter{"1FCC}{"1FC2}
\makelcletter{"1FFC}{"1FF2}

% letters with ypogegrammeni and perispomeni
\makelcletter{"1FBC}{"1FB7}
\makelcletter{"1FCC}{"1FC7}
\makelcletter{"1FFC}{"1FF7}

% capital letters with oxia
\makesameletter{"1FBB}{"0386}
\makesameletter{"1FC9}{"0388}
\makesameletter{"1FCB}{"0389}
\makesameletter{"1FDB}{"038A}
\makesameletter{"1FF9}{"038C}
\makesameletter{"1FEB}{"038E}
\makesameletter{"1FFB}{"038F}
 
% capital letters with varia (probably useless)
\makesameletter{"1FBA}{"1F70}
\makesameletter{"1FC8}{"1F72}
\makesameletter{"1FCA}{"1F74}
\makesameletter{"1FDA}{"1F76}
\makesameletter{"1FF8}{"1F78}
\makesameletter{"1FEA}{"1F7A}
\makesameletter{"1FFA}{"1F7C}

% Greek coronis
\catcode"2019=12 \lccode"2019="2019
\catcode"1FBD=12 \lccode"1FBD="2019
\catcode"1FBF=12 \lccode"1FBF="2019

\endinput
