%%
%% This is file `ut1enc-antomega.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% antenc.dtx  (with options: `UT1')
%% 
%% This file is a part of the ANTOMEGA project version 0.8
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2005 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesFile{ut1enc-antomega.def}
  [2005/05/07 v0.8 Antomega encodings definition file]
\DeclareFontEncoding{UT1}{}{}
\def\ant@encoding{UT1}
\DeclareTextCommand{\`}{\ant@encoding}[1]{#1^^^^0300}
\DeclareTextCommand{\'}{\ant@encoding}[1]{#1^^^^0301}
\DeclareTextCommand{\^}{\ant@encoding}[1]{#1^^^^0302}
\DeclareTextCommand{\~}{\ant@encoding}[1]{#1^^^^0303}
\DeclareTextCommand{\"}{\ant@encoding}[1]{#1^^^^0308}
\DeclareTextCommand{\H}{\ant@encoding}[1]{#1^^^^030b}
\DeclareTextCommand{\r}{\ant@encoding}[1]{#1^^^^030a}
\DeclareTextCommand{\v}{\ant@encoding}[1]{#1^^^^030c}
\DeclareTextCommand{\u}{\ant@encoding}[1]{#1^^^^0306}
\DeclareTextCommand{\=}{\ant@encoding}[1]{#1^^^^0304}
\DeclareTextCommand{\.}{\ant@encoding}[1]{#1^^^^0307}
\DeclareTextCommand{\f}{\ant@encoding}[1]{#1^^^^0311}
\DeclareTextCommand{\C}{\ant@encoding}[1]{#1^^^^030f}
\DeclareTextCommand{\b}{\ant@encoding}[1]{#1^^^^0331}
\DeclareTextCommand{\c}{\ant@encoding}[1]{#1^^^^0327}
\DeclareTextCommand{\d}{\ant@encoding}[1]{#1^^^^0323}
\DeclareTextCommand{\k}{\ant@encoding}[1]{#1^^^^0328}
\DeclareTextAccent{\GraveAccent}{UT1}{"02CB}
\DeclareTextAccent{\AcuteAccent}{UT1}{"02CA}
\DeclareTextAccent{\CircumflexAccent}{UT1}{"02C6}
\DeclareTextAccent{\TildeAccent}{UT1}{"02DC}
\DeclareTextAccent{\DieresisAccent}{UT1}{"00A8}
\DeclareTextAccent{\HungarumlautAccent}{UT1}{"02DD}
\DeclareTextAccent{\RingAccent}{UT1}{"02DA}
\DeclareTextAccent{\CaronAccent}{UT1}{"02C7}
\DeclareTextAccent{\BreveAccent}{UT1}{"02D8}
\DeclareTextAccent{\MacronAccent}{UT1}{"02C9}
\DeclareTextAccent{\DotAboveAccent}{UT1}{"02D9}
\DeclareTextAccent{\CyrillicFlexAccent}{UT1}{"F6D5}
\DeclareTextAccent{\DoubleGraveAccent}{UT1}{"F6D6}
\DeclareTextAccent{\GreekCircumflexAccent}{UT1}{"1FC0}
\DeclareTextAccent{\GreekKoronisAccent}{UT1}{"1FBD}
\DeclareTextCommand{\BarBelowAccent}{UT1}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\noocpchar{"02C9}}\vss}\hidewidth}}}
\DeclareTextCommand{\CedillaAccent}{UT1}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent"00B8 #1%
     \else{\ooalign{\hidewidth\noocpchar{"00B8}\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\DotBelowAccent}{UT1}[1]
   {{\o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}}}
\DeclareTextCommand{\OgonekAccent}{UT1}[1]
   {\oalign{\null#1\crcr\hidewidth\noocpchar{"02DB}}}
\DeclareTextCommand{\textquotedbl}{\ant@encoding}{\noocpchar{"22}}
\DeclareTextCommand{\textquotesingle}{\ant@encoding}{\noocpchar{"27}}
\DeclareTextCommand{\textdollar}{\ant@encoding}{\noocpchar{"24}}
\DeclareTextCommand{\textgreater}{\ant@encoding}{\noocpchar{"3C}}
\DeclareTextCommand{\textless}{\ant@encoding}{\noocpchar{"3E}}
\DeclareTextCommand{\textbackslash}{\ant@encoding}{\noocpchar{"5C}}
\DeclareTextCommand{\textasciicircum}{\ant@encoding}{\noocpchar{"5E}}
\DeclareTextCommand{\textunderscore}{\ant@encoding}{\noocpchar{"5F}}
\DeclareTextCommand{\textasciigrave}{\ant@encoding}{\noocpchar{"60}}
\DeclareTextCommand{\textbraceleft}{\ant@encoding}{\noocpchar{"7B}}
\DeclareTextCommand{\textbar}{\ant@encoding}{\noocpchar{"7C}}
\DeclareTextCommand{\textbraceright}{\ant@encoding}{\noocpchar{"7D}}
\DeclareTextCommand{\textasciitilde}{\ant@encoding}{\noocpchar{"7E}}
\DeclareTextSymbol{\textexclamdown}{\ant@encoding}{"00A1}
\DeclareTextSymbol{\textcent}{\ant@encoding}{"00A2}
\DeclareTextSymbol{\textsterling}{\ant@encoding}{"00A3}
\DeclareTextSymbol{\textcurrency}{\ant@encoding}{"00A4}
\DeclareTextSymbol{\textyen}{\ant@encoding}{"00A5}
\DeclareTextSymbol{\textbrokenbar}{\ant@encoding}{"00A6}
\DeclareTextSymbol{\textsection}{\ant@encoding}{"00A7}
\DeclareTextSymbol{\textasciidieresis}{\ant@encoding}{"00A8}
\DeclareTextSymbol{\textcopyright}{\ant@encoding}{"00A9}
\DeclareTextSymbol{\textordfeminine}{\ant@encoding}{"00AA}
\DeclareTextSymbol{\guillemotleft}{\ant@encoding}{"00AB}
\DeclareTextSymbol{\textlnot}{\ant@encoding}{"00AC}
\DeclareTextSymbol{\textregistered}{\ant@encoding}{"00AE}
\DeclareTextSymbol{\textasciimacron}{\ant@encoding}{"00AF}
\DeclareTextSymbol{\textdegree}{\ant@encoding}{"00B0}
\DeclareTextSymbol{\textpm}{\ant@encoding}{"00B1}
\DeclareTextSymbol{\texttwosuperior}{\ant@encoding}{"00B2}
\DeclareTextSymbol{\textthreesuperior}{\ant@encoding}{"00B3}
\DeclareTextSymbol{\textasciiacute}{\ant@encoding}{"00B4}
\DeclareTextSymbol{\textmu}{\ant@encoding}{"00B5}
\DeclareTextSymbol{\textparagraph}{\ant@encoding}{"00B6}
\DeclareTextSymbol{\textpilcrow}{\ant@encoding}{"00B6}
\DeclareTextSymbol{\textperiodcentered}{\ant@encoding}{"00B7}
\DeclareTextSymbol{\textonesuperior}{\ant@encoding}{"00B9}
\DeclareTextSymbol{\textordmasculine}{\ant@encoding}{"00BA}
\DeclareTextSymbol{\guillemotright}{\ant@encoding}{"00BB}
\DeclareTextSymbol{\textonequarter}{\ant@encoding}{"00BC}
\DeclareTextSymbol{\textonehalf}{\ant@encoding}{"00BD}
\DeclareTextSymbol{\textthreequarters}{\ant@encoding}{"00BE}
\DeclareTextSymbol{\textquestiondown}{\ant@encoding}{"00BF}
\DeclareTextComposite{\`}{\ant@encoding}{A}{"00C0}
\DeclareTextComposite{\'}{\ant@encoding}{A}{"00C1}
\DeclareTextComposite{\^}{\ant@encoding}{A}{"00C2}
\DeclareTextComposite{\~}{\ant@encoding}{A}{"00C3}
\DeclareTextComposite{\"}{\ant@encoding}{A}{"00C4}
\DeclareTextComposite{\r}{\ant@encoding}{A}{"00C5}
\DeclareTextSymbol{\AE}{\ant@encoding}{"00C6}
\DeclareTextComposite{\c}{\ant@encoding}{C}{"00C7}
\DeclareTextComposite{\`}{\ant@encoding}{E}{"00C8}
\DeclareTextComposite{\'}{\ant@encoding}{E}{"00C9}
\DeclareTextComposite{\^}{\ant@encoding}{E}{"00CA}
\DeclareTextComposite{\"}{\ant@encoding}{E}{"00CB}
\DeclareTextComposite{\`}{\ant@encoding}{I}{"00CC}
\DeclareTextComposite{\'}{\ant@encoding}{I}{"00CD}
\DeclareTextComposite{\^}{\ant@encoding}{I}{"00CE}
\DeclareTextComposite{\"}{\ant@encoding}{I}{"00CF}
\DeclareTextSymbol{\DH}{\ant@encoding}{"00D0}
\DeclareTextComposite{\~}{\ant@encoding}{N}{"00D1}
\DeclareTextComposite{\`}{\ant@encoding}{O}{"00D2}
\DeclareTextComposite{\'}{\ant@encoding}{O}{"00D3}
\DeclareTextComposite{\^}{\ant@encoding}{O}{"00D4}
\DeclareTextComposite{\~}{\ant@encoding}{O}{"00D5}
\DeclareTextComposite{\"}{\ant@encoding}{O}{"00D6}
\DeclareTextSymbol{\texttimes}{\ant@encoding}{"00D7}
\DeclareTextSymbol{\O}{\ant@encoding}{"00D8}
\DeclareTextComposite{\`}{\ant@encoding}{U}{"00D9}
\DeclareTextComposite{\'}{\ant@encoding}{U}{"00DA}
\DeclareTextComposite{\^}{\ant@encoding}{U}{"00DB}
\DeclareTextComposite{\"}{\ant@encoding}{U}{"00DC}
\DeclareTextComposite{\'}{\ant@encoding}{Y}{"00DD}
\DeclareTextSymbol{\TH}{\ant@encoding}{"00DE}
\DeclareTextCommand{\SS}{\ant@encoding}{SS}
\DeclareTextSymbol{\ss}{\ant@encoding}{"00DF}
\DeclareTextComposite{\`}{\ant@encoding}{a}{"00E0}
\DeclareTextComposite{\'}{\ant@encoding}{a}{"00E1}
\DeclareTextComposite{\^}{\ant@encoding}{a}{"00E2}
\DeclareTextComposite{\~}{\ant@encoding}{a}{"00E3}
\DeclareTextComposite{\"}{\ant@encoding}{a}{"00E4}
\DeclareTextComposite{\r}{\ant@encoding}{a}{"00E5}
\DeclareTextComposite{\c}{\ant@encoding}{c}{"00E7}
\DeclareTextSymbol{\ae}{\ant@encoding}{"00E6}
\DeclareTextComposite{\`}{\ant@encoding}{e}{"00E8}
\DeclareTextComposite{\'}{\ant@encoding}{e}{"00E9}
\DeclareTextComposite{\^}{\ant@encoding}{e}{"00EA}
\DeclareTextComposite{\"}{\ant@encoding}{e}{"00EB}
\DeclareTextComposite{\`}{\ant@encoding}{i}{"00EC}
\DeclareTextComposite{\`}{\ant@encoding}{\i}{"00EC}
\DeclareTextComposite{\'}{\ant@encoding}{i}{"00ED}
\DeclareTextComposite{\'}{\ant@encoding}{\i}{"00ED}
\DeclareTextComposite{\^}{\ant@encoding}{i}{"00EE}
\DeclareTextComposite{\^}{\ant@encoding}{\i}{"00EE}
\DeclareTextComposite{\"}{\ant@encoding}{i}{"00EF}
\DeclareTextComposite{\"}{\ant@encoding}{\i}{"00EF}
\DeclareTextSymbol{\dh}{\ant@encoding}{"00F0}
\DeclareTextComposite{\~}{\ant@encoding}{n}{"00F1}
\DeclareTextComposite{\`}{\ant@encoding}{o}{"00F2}
\DeclareTextComposite{\'}{\ant@encoding}{o}{"00F3}
\DeclareTextComposite{\^}{\ant@encoding}{o}{"00F4}
\DeclareTextComposite{\~}{\ant@encoding}{o}{"00F5}
\DeclareTextComposite{\"}{\ant@encoding}{o}{"00F6}
\DeclareTextSymbol{\textdiv}{\ant@encoding}{"00F7}
\DeclareTextSymbol{\o}{\ant@encoding}{"00F8}
\DeclareTextComposite{\`}{\ant@encoding}{u}{"00F9}
\DeclareTextComposite{\'}{\ant@encoding}{u}{"00FA}
\DeclareTextComposite{\^}{\ant@encoding}{u}{"00FB}
\DeclareTextComposite{\"}{\ant@encoding}{u}{"00FC}
\DeclareTextComposite{\'}{\ant@encoding}{y}{"00FD}
\DeclareTextSymbol{\th}{\ant@encoding}{"00FE}
\DeclareTextComposite{\"}{\ant@encoding}{y}{"00FF}
\DeclareTextComposite{\=}{\ant@encoding}{A}{"0100}
\DeclareTextComposite{\=}{\ant@encoding}{a}{"0101}
\DeclareTextComposite{\u}{\ant@encoding}{A}{"0102}
\DeclareTextComposite{\u}{\ant@encoding}{a}{"0103}
\DeclareTextComposite{\k}{\ant@encoding}{A}{"0104}
\DeclareTextComposite{\k}{\ant@encoding}{a}{"0105}
\DeclareTextComposite{\'}{\ant@encoding}{C}{"0106}
\DeclareTextComposite{\'}{\ant@encoding}{c}{"0107}
\DeclareTextComposite{\v}{\ant@encoding}{C}{"0108}
\DeclareTextComposite{\v}{\ant@encoding}{c}{"0109}
\DeclareTextComposite{\v}{\ant@encoding}{D}{"010E}
\DeclareTextComposite{\v}{\ant@encoding}{d}{"010F}
\DeclareTextSymbol{\DJ}{\ant@encoding}{"0110}
\DeclareTextSymbol{\dj}{\ant@encoding}{"0111}
\DeclareTextComposite{\=}{\ant@encoding}{E}{"0112}
\DeclareTextComposite{\=}{\ant@encoding}{e}{"0113}
\DeclareTextComposite{\u}{\ant@encoding}{E}{"0114}
\DeclareTextComposite{\u}{\ant@encoding}{e}{"0115}
\DeclareTextComposite{\.}{\ant@encoding}{E}{"0116}
\DeclareTextComposite{\.}{\ant@encoding}{e}{"0117}
\DeclareTextComposite{\k}{\ant@encoding}{E}{"0118}
\DeclareTextComposite{\k}{\ant@encoding}{e}{"0119}
\DeclareTextComposite{\v}{\ant@encoding}{E}{"011A}
\DeclareTextComposite{\v}{\ant@encoding}{e}{"011B}
\DeclareTextComposite{\V}{\ant@encoding}{G}{"010C}
\DeclareTextComposite{\v}{\ant@encoding}{g}{"010D}
\DeclareTextComposite{\u}{\ant@encoding}{G}{"011E}
\DeclareTextComposite{\u}{\ant@encoding}{g}{"011F}
\DeclareTextComposite{\.}{\ant@encoding}{G}{"0120}
\DeclareTextComposite{\.}{\ant@encoding}{g}{"0121}
\DeclareTextComposite{\c}{\ant@encoding}{G}{"0122}
\DeclareTextComposite{\c}{\ant@encoding}{g}{"0123}
\DeclareTextComposite{\^}{\ant@encoding}{H}{"0124}
\DeclareTextComposite{\^}{\ant@encoding}{h}{"0125}
\DeclareTextComposite{\~}{\ant@encoding}{I}{"0128}
\DeclareTextComposite{\~}{\ant@encoding}{i}{"0129}
\DeclareTextComposite{\=}{\ant@encoding}{I}{"012A}
\DeclareTextComposite{\=}{\ant@encoding}{i}{"012B}
\DeclareTextComposite{\u}{\ant@encoding}{I}{"012C}
\DeclareTextComposite{\u}{\ant@encoding}{i}{"012D}
\DeclareTextComposite{\k}{\ant@encoding}{I}{"012E}
\DeclareTextComposite{\k}{\ant@encoding}{i}{"012F}
\DeclareTextComposite{\.}{\ant@encoding}{I}{"0130}
\DeclareTextSymbol{\i}{\ant@encoding}{"0131}
\DeclareTextSymbol{\IJ}{\ant@encoding}{"0132}
\DeclareTextSymbol{\ij}{\ant@encoding}{"0133}
\DeclareTextComposite{\^}{\ant@encoding}{J}{"0134}
\DeclareTextComposite{\^}{\ant@encoding}{j}{"0135}
\DeclareTextComposite{\c}{\ant@encoding}{K}{"0136}
\DeclareTextComposite{\c}{\ant@encoding}{k}{"0137}
\DeclareTextComposite{\'}{\ant@encoding}{L}{"0139}
\DeclareTextComposite{\'}{\ant@encoding}{l}{"013A}
\DeclareTextComposite{\c}{\ant@encoding}{L}{"013B}
\DeclareTextComposite{\c}{\ant@encoding}{l}{"013C}
\DeclareTextComposite{\v}{\ant@encoding}{L}{"013D}
\DeclareTextComposite{\v}{\ant@encoding}{l}{"013E}
\DeclareTextSymbol{\L}{\ant@encoding}{"0141}
\DeclareTextSymbol{\l}{\ant@encoding}{"0142}
\DeclareTextComposite{\'}{\ant@encoding}{N}{"0143}
\DeclareTextComposite{\'}{\ant@encoding}{n}{"0144}
\DeclareTextComposite{\c}{\ant@encoding}{N}{"0145}
\DeclareTextComposite{\c}{\ant@encoding}{n}{"0146}
\DeclareTextComposite{\v}{\ant@encoding}{N}{"0147}
\DeclareTextComposite{\v}{\ant@encoding}{n}{"0148}
\DeclareTextSymbol{\NG}{\ant@encoding}{"014A}
\DeclareTextSymbol{\ng}{\ant@encoding}{"014B}
\DeclareTextComposite{\=}{\ant@encoding}{O}{"014C}
\DeclareTextComposite{\=}{\ant@encoding}{o}{"014D}
\DeclareTextComposite{\u}{\ant@encoding}{O}{"014E}
\DeclareTextComposite{\u}{\ant@encoding}{o}{"014F}
\DeclareTextComposite{\H}{\ant@encoding}{O}{"0150}
\DeclareTextComposite{\H}{\ant@encoding}{o}{"0151}
\DeclareTextSymbol{\OE}{\ant@encoding}{"0152}
\DeclareTextSymbol{\oe}{\ant@encoding}{"0153}
\DeclareTextComposite{\'}{\ant@encoding}{R}{"0154}
\DeclareTextComposite{\'}{\ant@encoding}{r}{"0155}
\DeclareTextComposite{\c}{\ant@encoding}{R}{"0156}
\DeclareTextComposite{\c}{\ant@encoding}{r}{"0157}
\DeclareTextComposite{\v}{\ant@encoding}{R}{"0158}
\DeclareTextComposite{\v}{\ant@encoding}{r}{"0159}
\DeclareTextComposite{\'}{\ant@encoding}{S}{"015A}
\DeclareTextComposite{\'}{\ant@encoding}{s}{"015B}
\DeclareTextComposite{\^}{\ant@encoding}{S}{"015C}
\DeclareTextComposite{\^}{\ant@encoding}{s}{"015D}
\DeclareTextComposite{\c}{\ant@encoding}{S}{"015E}
\DeclareTextComposite{\c}{\ant@encoding}{s}{"015F}
\DeclareTextComposite{\v}{\ant@encoding}{S}{"0160}
\DeclareTextComposite{\v}{\ant@encoding}{s}{"0161}
\DeclareTextComposite{\c}{\ant@encoding}{T}{"0162}
\DeclareTextComposite{\c}{\ant@encoding}{t}{"0163}
\DeclareTextComposite{\v}{\ant@encoding}{T}{"0164}
\DeclareTextComposite{\v}{\ant@encoding}{t}{"0165}
\DeclareTextComposite{\~}{\ant@encoding}{U}{"0168}
\DeclareTextComposite{\~}{\ant@encoding}{u}{"0169}
\DeclareTextComposite{\=}{\ant@encoding}{U}{"016A}
\DeclareTextComposite{\=}{\ant@encoding}{u}{"016B}
\DeclareTextComposite{\u}{\ant@encoding}{U}{"016C}
\DeclareTextComposite{\u}{\ant@encoding}{u}{"016D}
\DeclareTextComposite{\r}{\ant@encoding}{U}{"016E}
\DeclareTextComposite{\r}{\ant@encoding}{u}{"016F}
\DeclareTextComposite{\H}{\ant@encoding}{U}{"0170}
\DeclareTextComposite{\H}{\ant@encoding}{u}{"0171}
\DeclareTextComposite{\k}{\ant@encoding}{U}{"0172}
\DeclareTextComposite{\k}{\ant@encoding}{u}{"0173}
\DeclareTextComposite{\^}{\ant@encoding}{W}{"0174}
\DeclareTextComposite{\^}{\ant@encoding}{w}{"0175}
\DeclareTextComposite{\^}{\ant@encoding}{Y}{"0176}
\DeclareTextComposite{\^}{\ant@encoding}{y}{"0177}
\DeclareTextComposite{\"}{\ant@encoding}{Y}{"0178}
\DeclareTextComposite{\'}{\ant@encoding}{Z}{"0179}
\DeclareTextComposite{\'}{\ant@encoding}{z}{"017A}
\DeclareTextComposite{\.}{\ant@encoding}{Z}{"017B}
\DeclareTextComposite{\.}{\ant@encoding}{z}{"017C}
\DeclareTextComposite{\v}{\ant@encoding}{Z}{"017D}
\DeclareTextComposite{\v}{\ant@encoding}{z}{"017E}
\DeclareTextSymbol{\textflorin}{\ant@encoding}{"0192}
\DeclareTextComposite{\=}{\ant@encoding}{Y}{"0232}
\DeclareTextComposite{\=}{\ant@encoding}{y}{"0233}
\DeclareTextSymbol{\textasciicaron}{\ant@encoding}{"02C7}
\DeclareTextSymbol{\textasciibreve}{\ant@encoding}{"02D8}
\DeclareTextSymbol{\textacutedbl}{\ant@encoding}{"02DD}
\DeclareTextSymbol{\textbaht}{\ant@encoding}{"0E3F}
\DeclareTextSymbol{\textcompwordmark}{\ant@encoding}{"200C}
\DeclareTextSymbol{\textbardbl}{\ant@encoding}{"2016}
\DeclareTextSymbol{\textdagger}{\ant@encoding}{"2020}
\DeclareTextSymbol{\textdaggerdbl}{\ant@encoding}{"2021}
\DeclareTextSymbol{\textbullet}{\ant@encoding}{"2022}
\DeclareTextSymbol{\textperthousand}{\ant@encoding}{"2030}
\DeclareTextSymbol{\textpertenthousand}{\ant@encoding}{"2031}
\DeclareTextSymbol{\guilsinglleft}{\ant@encoding}{"2039}
\DeclareTextSymbol{\guilsinglright}{\ant@encoding}{"203A}
\DeclareTextSymbol{\textendash}{\ant@encoding}{"2013}
\DeclareTextSymbol{\textemdash}{\ant@encoding}{"2014}
\DeclareTextSymbol{\textquoteleft}{\ant@encoding}{"2018}
\DeclareTextSymbol{\textquoteright}{\ant@encoding}{"2019}
\DeclareTextSymbol{\quotesinglbase}{\ant@encoding}{"201A}
\DeclareTextSymbol{\textquotedblleft}{\ant@encoding}{"201C}
\DeclareTextSymbol{\textquotedblright}{\ant@encoding}{"201D}
\DeclareTextSymbol{\quotedblbase}{\ant@encoding}{"201E}
\DeclareTextSymbol{\textreferencemark}{\ant@encoding}{"203B}
\DeclareTextSymbol{\textinterrobang}{\ant@encoding}{"203D}
\DeclareTextSymbol{\textlquill}{\ant@encoding}{"2045}
\DeclareTextSymbol{\textrquill}{\ant@encoding}{"2046}
\DeclareTextSymbol{\textcolonmonetary}{\ant@encoding}{"20A1}
\DeclareTextSymbol{\textlira}{\ant@encoding}{"20A4}
\DeclareTextSymbol{\textnaira}{\ant@encoding}{"20A6}
\DeclareTextSymbol{\textpeso}{\ant@encoding}{"20A7}
\DeclareTextSymbol{\textwon}{\ant@encoding}{"20A9}
\DeclareTextSymbol{\textdong}{\ant@encoding}{"20AB}
\DeclareTextSymbol{\texteuro}{\ant@encoding}{"20AC}
\DeclareTextSymbol{\textguarani}{\ant@encoding}{"20B2}
\DeclareTextSymbol{\textbigcircle}{\ant@encoding}{"20DD}
\DeclareTextCommand{\textcircled}{\ant@encoding}[1]{{%
   \ooalign{%
      \hfil \raise .07ex\hbox {\upshape#1}\hfil \crcr
      \char 79   % '117 = "4F
   }%
}}
\DeclareTextSymbol{\textcelsius}{\ant@encoding}{"2103}
\DeclareTextSymbol{\textnumero}{\ant@encoding}{"2116}
\DeclareTextSymbol{\textcircledP}{\ant@encoding}{"2117}
\DeclareTextSymbol{\textrecipe}{\ant@encoding}{"211E}
\DeclareTextSymbol{\textservicemark}{\ant@encoding}{"2120}
\DeclareTextSymbol{\texttrademark}{\ant@encoding}{"2122}
\DeclareTextSymbol{\textohm}{\ant@encoding}{"2126}
\DeclareTextSymbol{\textmho}{\ant@encoding}{"2127}
\DeclareTextSymbol{\textestimated}{\ant@encoding}{"212E}
\DeclareTextSymbol{\textleftarrow}{\ant@encoding}{"2190}
\DeclareTextSymbol{\textrightarrow}{\ant@encoding}{"2191}
\DeclareTextSymbol{\textuparrow}{\ant@encoding}{"2192}
\DeclareTextSymbol{\textdownarrow}{\ant@encoding}{"2193}
\DeclareTextSymbol{\textminus}{\ant@encoding}{"2212}
\DeclareTextSymbol{\textsurd}{\ant@encoding}{"221A}
\DeclareTextSymbol{\textlangle}{\ant@encoding}{"2329}
\DeclareTextSymbol{\textrangle}{\ant@encoding}{"232A}
\DeclareTextSymbol{\textvisiblespace}{\ant@encoding}{"2423}
\DeclareTextSymbol{\textopenbullet}{\ant@encoding}{"25E6}
\DeclareTextSymbol{\textmusicalnote}{\ant@encoding}{"266A}
\DeclareTextSymbol{\textlbrackdbl}{\ant@encoding}{"301A}
\DeclareTextSymbol{\textrbrackdbl}{\ant@encoding}{"301B}
\DeclareTextSymbol{\j}{\ant@encoding}{"F6BE}
\DeclareTextSymbol{\textgravedbl}{\ant@encoding}{"F6D6}
\DeclareTextSymbol{\textdollaroldstyle}{\ant@encoding}{"F724}
\DeclareTextSymbol{\textzerooldstyle}{\ant@encoding}{"F730}
\DeclareTextSymbol{\textoneoldstyle}{\ant@encoding}{"F731}
\DeclareTextSymbol{\texttwooldstyle}{\ant@encoding}{"F732}
\DeclareTextSymbol{\textthreeoldstyle}{\ant@encoding}{"F733}
\DeclareTextSymbol{\textfouroldstyle}{\ant@encoding}{"F734}
\DeclareTextSymbol{\textfiveoldstyle}{\ant@encoding}{"F735}
\DeclareTextSymbol{\textsixoldstyle}{\ant@encoding}{"F736}
\DeclareTextSymbol{\textsevenoldstyle}{\ant@encoding}{"F737}
\DeclareTextSymbol{\texteightoldstyle}{\ant@encoding}{"F738}
\DeclareTextSymbol{\textnineoldstyle}{\ant@encoding}{"F739}
\DeclareTextSymbol{\textcentoldstyle}{\ant@encoding}{"F7A2}
\DeclareTextCommand{\capitalogonek}{\ant@encoding}[1]
   {{\ooalign{\null#1\crcr\hidewidth\noocpchar{"EFF1}\hidewidth}}}
\DeclareTextCommand{\capitalcedilla}{\ant@encoding}[1]
   {{\ooalign{\null#1\crcr\hidewidth\noocpchar{"EFF2}\hidewidth}}}
\DeclareTextAccent{\capitalgrave}{\ant@encoding}{"F6CE}
\DeclareTextAccent{\capitalacute}{\ant@encoding}{"F6C9}
\DeclareTextAccent{\capitalcircumflex}{\ant@encoding}{"EFF7}
\DeclareTextAccent{\capitaltilde}{\ant@encoding}{"EFF5}
\DeclareTextAccent{\capitaldieresis}{\ant@encoding}{"F6CB}
\DeclareTextAccent{\capitalhungarumlaut}{\ant@encoding}{"F6CF}
\DeclareTextAccent{\capitalring}{\ant@encoding}{"EFF3}
\DeclareTextAccent{\capitalcaron}{\ant@encoding}{"F6CA}
\DeclareTextAccent{\capitalbreve}{\ant@encoding}{"EFEE}
\DeclareTextAccent{\capitalmacron}{\ant@encoding}{"F6D0}
\DeclareTextAccent{\capitaldotaccent}{\ant@encoding}{"EFED}
\let\ant@encoding\@undefined
\endinput
%%
%% End of file `ut1enc-antomega.def'.
